| Title: | Discover and Install Useful RStudio Addins |
|---|---|
| Description: | Browse through a continuously updated list of existing RStudio addins and install/uninstall their corresponding packages. |
| Authors: | Dean Attali [aut, cre] (ORCID: <https://orcid.org/0000-0002-5645-3493>) |
| Maintainer: | Dean Attali <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.5.0 |
| Built: | 2026-05-21 07:15:28 UTC |
| Source: | https://github.com/daattali/addinslist |
This addin allows you to interactively browse through the list of existing addins, see which ones you already have installed, and let you install/uninstall the corresponding package of each addin. This addin can be invoked from RStudio's "Addins" menu.
addinslistAddin()addinslistAddin()
if (interactive()) { addinslistAddin() }if (interactive()) { addinslistAddin() }